==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiWidgets/QFormLayout_shell.h <==
#ifndef QFORMLAYOUT_SHELL_H
#define QFORMLAYOUT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <qtwidgets-config.h>
#if QT_CONFIG(formlayout)
#include <QtWidgets/qformlayout.h>
#endif //QT_CONFIG(formlayout)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qlayoutitem.h>
#include <QtWidgets/qwidget.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(formlayout)

class QFormLayout_shell : public QFormLayout, public QtJambiShellInterface
{
public:
    QFormLayout_shell(QWidget* parent0 = nullptr);
    ~QFormLayout_shell() override;

    void addItem(QLayoutItem* item0) override;
    void childEvent(QChildEvent* e0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QSizePolicy::ControlTypes controlTypes() const override;
    int count() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    Qt::Orientations expandingDirections() const override;
    QRect geometry() const override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int width0) const override;
    int indexOf(QWidget* arg__1) const override;
    void invalidate() override;
    bool isEmpty() const override;
    QLayoutItem* itemAt(int index0) const override;
    QLayout* layout() override;
    QSize maximumSize() const override;
    int minimumHeightForWidth(int arg__1) const override;
    QSize minimumSize() const override;
    void setGeometry(const QRect& rect0) override;
    QSize sizeHint() const override;
    QSpacerItem* spacerItem() override;
    QLayoutItem* takeAt(int index0) override;
    void timerEvent(QTimerEvent* event0) override;
    QWidget* widget() override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QFormLayout_access : public QFormLayout
{
    void __qt_addItem_QLayoutItem_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0);
    jint __qt_count(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_expandingDirections(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasHeightForWidth(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_heightForWidth_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint width0) const;
    void __qt_invalidate(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_itemAt_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
    jobject __qt_minimumSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setGeometry_cref_QRect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID rect0);
    jobject __qt_sizeHint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_takeAt_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0);
};

#endif // QT_CONFIG(formlayout)
#endif // QFORMLAYOUT_SHELL_H

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiWidgets/QFormLayout_shell.h <==
#ifndef QFORMLAYOUT_SHELL_H
#define QFORMLAYOUT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(formlayout)
#include <QtWidgets/qformlayout.h>
#endif //QT_CONFIG(formlayout)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qlayoutitem.h>
#include <QtWidgets/qwidget.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(formlayout)

class QFormLayout_shell : public QFormLayout, public QtJambiShellInterface
{
public:
    QFormLayout_shell(QWidget* parent0 = nullptr);
    ~QFormLayout_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QFormLayout_mshell;
    friend class QFormLayout_oshell;
};


class QFormLayout_mshell : public QFormLayout_shell
{
public:
    using QFormLayout_shell::QFormLayout_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QFormLayout_oshell : public QFormLayout_mshell
{
public:
    using QFormLayout_mshell::QFormLayout_mshell;
    void addItem(QLayoutItem* item0) override;
    void childEvent(QChildEvent* e0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QSizePolicy::ControlTypes controlTypes() const override;
    int count() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    Qt::Orientations expandingDirections() const override;
    QRect geometry() const override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int width0) const override;
    int indexOf(const QLayoutItem* arg__1) const override;
    int indexOf(const QWidget* arg__1) const override;
    void invalidate() override;
    bool isEmpty() const override;
    QLayoutItem* itemAt(int index0) const override;
    QLayout* layout() override;
    QSize maximumSize() const override;
    int minimumHeightForWidth(int arg__1) const override;
    QSize minimumSize() const override;
    QLayoutItem* replaceWidget(QWidget* from0, QWidget* to1, Qt::FindChildOptions options2) override;
    void setGeometry(const QRect& rect0) override;
    QSize sizeHint() const override;
    QSpacerItem* spacerItem() override;
    QLayoutItem* takeAt(int index0) override;
    void timerEvent(QTimerEvent* event0) override;
    QWidget* widget() const override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QFormLayout_access : public QFormLayout
{
    void __qt_addItem_QLayoutItem_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0);
    jint __qt_count_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_expandingDirections_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasHeightForWidth_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_heightForWidth_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint width0) const;
    void __qt_invalidate(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_itemAt_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
    jobject __qt_minimumSize_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setGeometry_cref_QRect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID rect0);
    jobject __qt_sizeHint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_takeAt_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0);
};

#endif // QT_CONFIG(formlayout)
#endif // QFORMLAYOUT_SHELL_H
